package org.security.system.user.feign;

import org.security.system.user.entity.User;
import org.security.system.user.entity.UserDept;
import org.security.system.user.entity.UserInfo;
import org.security.system.user.entity.UserOauth;
import org.security.system.user.vo.UserVO;
import org.springblade.core.tool.api.R;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author ：wzf
 * @apiNote ：user 服务熔断机制
 * @since ：Created in 2022/9/19 14:19
 */
@Component
public class UserClientFallback implements IUserClient{
	@Override
	public R<User> userInfoById(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<User> userByAccount(String tenantId, String account) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<UserInfo> userInfo(String tenantId, String account) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<UserInfo> userInfo(String tenantId, String account, String userType) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<UserInfo> userAuthInfo(UserOauth userOauth) {
		return R.fail("远程调用失败");
	}

	@Override
	public R saveUser(User user) {
		return R.fail("远程调用失败");
	}

	@Override
	public R removeUser(String tenantIds) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<UserVO> getUserByCode(String code) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> headLeaders(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> headSecLeaders(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> headSafers(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> branchLeaders(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> branchSafers(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> subLeaders(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> subSafers(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> deptLeaders(Long userId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> headSecCenterAll() {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> branchSecCenterAll() {
		return R.fail("远程调用失败");
	}

	@Override
	public R removeUserDept(List<String> userIds) {
		return R.fail("远程调用失败");
	}

	@Override
	public R saveUserDept(List<UserDept> userDeptList) {
		return R.fail("远程调用失败");
	}

	@Override
	public R saveUserData(List<User> userList) {
		return R.fail("远程调用失败");
	}

	@Override
	public R<List<UserVO>> getUserByRoleId(String roleId) {
		return R.fail("远程调用失败");
	}

	@Override
	public R getUsersByUserIds(String userIds) {
		return R.fail("远程调用失败");
	}

	@Override
	public R userHasRoleAlias(String tenantId, Long userId, String roleAlias) {
		return R.fail("远程调用失败");
	}
}
